==> 0.0.6.tar.gz: lib/nui_bottom_nav_pager.dart <==
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/nui_core.dart';

typedef ClickListenerOverride = void Function(BuildContext context);

class NUIBlankScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

class NUIBottomNavItem extends BottomNavigationBarItem{
  NUIBottomNavItem({@required this.id, @required Widget icon, Widget activeIcon, String label, Color backgroundColor, this.listenerOverride}): super(icon: icon, activeIcon: activeIcon, label: label, backgroundColor: backgroundColor);
  String id;
  ClickListenerOverride listenerOverride;
}

class NUIBottomNavPage extends StatefulWidget {
  NUIBottomNavPage({Key key, @required this.pages, this.wrapInVisible: false, this.navBorderRadius, this.shadowColor, this.shadowRadius, this.shadowOffset, @required this.navItems, this.backgroundColor, this.bottomNavColor, this.startingPage:0, this.showSelectedLabels:true, this.showUnselectedLabels:true, this.elevation:1, this.animate:true}) : super(key: key);
  final List<Widget> pages;
  final List<NUIBottomNavItem> navItems;
  final int startingPage;
  final bool showSelectedLabels;
  final bool showUnselectedLabels;
  final double elevation;
  final bool animate;
  final Color backgroundColor;
  final Color bottomNavColor;
  final bool wrapInVisible;
  final Color shadowColor;
  final Offset shadowOffset;
  final double shadowRadius;
  final BorderRadius navBorderRadius;
  @override
  _NUIBottomNavPageState createState() => _NUIBottomNavPageState(startingPage);
}

class _NUIBottomNavPageState extends State<NUIBottomNavPage> {
  int _currentIndex;
  int _startindIndex;
  _NUIBottomNavPageState(this._currentIndex);
  List<Widget> pages;

  @override
  void initState(){
    super.initState();
    this.pages = _getPages();
    this._startindIndex = widget.startingPage ?? 0;
  }

  void _onNavItemClick(BuildContext context, int index){
    final navItem = widget.navItems[index];
    if(navItem.listenerOverride != null){
      navItem.listenerOverride(context);
    }
    else{
      setState(() {
        _currentIndex = index;
      });
    }
  }

  List<Widget> _getPages(){
    if(widget.wrapInVisible == true) {
      int index = -1;
      return widget.pages.map((e) {
        index ++;
        return NUITabChildStatefulWidget(onScreenContent: e,
            backgroundContent: _startindIndex != index ? Center(
                child: CircularProgressIndicator(
                    valueColor: AlwaysStoppedAnimation<Color>(NUIColors.NUITextBlack),
                    strokeWidth: 2.0,
                    backgroundColor: NUIColors.NUISkeletalGray
                )
            ) : null
        );
      }).toList();
    }
    return widget.pages;
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async{
        if(_currentIndex == 0){
          log("NUIBottomNavPage -> Popping entire page");
          return true;
        }
        setState(() {
          log("NUIBottomNavPage -> Returning to first page from page $_currentIndex");
          _currentIndex = 0;
        });
        return false;
      },
      child: Scaffold(
        backgroundColor: widget.backgroundColor ?? NUIColors.NUIWhite,
        body: IndexedStack(
          index: _currentIndex,
          children: pages,
        ),
        bottomNavigationBar: Container(
          decoration: NUIBoxDecoration(
              shadowColor: widget.shadowColor ?? NUIColors.NUIBlack.withOpacity(0.7),
              shadowRadius: widget.elevation ?? 0,
              shadowOffset: widget.shadowOffset ?? Offset(0, 0),
              borderRadius: widget.navBorderRadius ?? BorderRadius.circular(0),
              color: widget.bottomNavColor ?? NUIColors.NUIWhite
          ),
          child: BottomNavigationBar(
            onTap: (int index) {
              logNUI('NUIBottomNavPager', 'Tapping on $index');
              _onNavItemClick(context, index);
            },
            backgroundColor: NUIColors.NUITransparent,
            currentIndex: _currentIndex,
            showSelectedLabels: widget.showSelectedLabels,
            showUnselectedLabels: widget.showUnselectedLabels,
            items: widget.navItems,
            elevation: 0,
            type: widget.animate ? BottomNavigationBarType.shifting : BottomNavigationBarType.fixed,
          ),
        ),
      ),
    );
  }
}

==> 0.0.40.tar.gz: lib/nui_bottom_nav_pager.dart <==
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/nui_core.dart';

typedef ClickListenerOverride = void Function(BuildContext context);

class NUIBlankScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

class NUIBottomNavItem extends BottomNavigationBarItem{
  NUIBottomNavItem({@required this.id, @required Widget icon, Widget activeIcon, String label, Color backgroundColor, this.listenerOverride}): super(icon: icon, activeIcon: activeIcon, label: label, backgroundColor: backgroundColor);
  String id;
  ClickListenerOverride listenerOverride;
}

typedef NUIBottomNavPageUpdateListener = void Function(int index);
class NUIBottomNavPageController{
  NUIBottomNavPageUpdateListener _pageUpdateListener;
  void setCurrentPage(int page){
    if(_pageUpdateListener != null) _pageUpdateListener(page);
  }
}

class NUIBottomNavPage extends StatefulWidget {
  NUIBottomNavPage({Key key, @required this.pages, this.controller, this.wrapInVisible: false, this.navBorderRadius, this.shadowColor, this.shadowRadius, this.shadowOffset, @required this.navItems, this.backgroundColor, this.bottomNavColor, this.startingPage:0, this.showSelectedLabels:true, this.showUnselectedLabels:true, this.elevation:1, this.animate:true}) : super(key: key);
  final List<Widget> pages;
  final List<NUIBottomNavItem> navItems;
  final int startingPage;
  final bool showSelectedLabels;
  final bool showUnselectedLabels;
  final double elevation;
  final bool animate;
  final Color backgroundColor;
  final Color bottomNavColor;
  final bool wrapInVisible;
  final Color shadowColor;
  final Offset shadowOffset;
  final double shadowRadius;
  final BorderRadius navBorderRadius;
  final NUIBottomNavPageController controller;
  @override
  _NUIBottomNavPageState createState() => _NUIBottomNavPageState(startingPage);
}

class _NUIBottomNavPageState extends State<NUIBottomNavPage> {
  int _currentIndex;
  int _startindIndex;
  _NUIBottomNavPageState(this._currentIndex);
  List<Widget> pages;
  NUIBottomNavPageController controller;

  @override
  void initState(){
    super.initState();
    this.pages = _getPages();
    this._startindIndex = widget.startingPage ?? 0;
    controller = widget.controller ?? NUIBottomNavPageController();
    controller._pageUpdateListener = (page){
      _onNavItemClick(context, page);
    };
  }

  void _onNavItemClick(BuildContext context, int index){
    final navItem = widget.navItems[index];
    if(navItem.listenerOverride != null){
      navItem.listenerOverride(context);
    }
    else{
      setState(() {
        _currentIndex = index;
      });
    }
  }

  List<Widget> _getPages(){
    if(widget.wrapInVisible == true) {
      int index = -1;
      return widget.pages.map((e) {
        index ++;
        return NUITabChildStatefulWidget(onScreenContent: e,
            backgroundContent: _startindIndex != index ? Center(
                child: CircularProgressIndicator(
                    valueColor: AlwaysStoppedAnimation<Color>(NUIColors.NUITextBlack),
                    strokeWidth: 2.0,
                    backgroundColor: NUIColors.NUISkeletalGray
                )
            ) : null
        );
      }).toList();
    }
    return widget.pages;
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async{
        if(_currentIndex == 0){
          log("NUIBottomNavPage -> Popping entire page");
          return true;
        }
        setState(() {
          log("NUIBottomNavPage -> Returning to first page from page $_currentIndex");
          _currentIndex = 0;
        });
        return false;
      },
      child: Scaffold(
        backgroundColor: widget.backgroundColor ?? NUIColors.NUIWhite,
        body: IndexedStack(
          index: _currentIndex,
          children: pages,
        ),
        bottomNavigationBar: Container(
          decoration: NUIBoxDecoration(
              shadowColor: widget.shadowColor ?? NUIColors.NUIBlack.withOpacity(0.7),
              shadowRadius: widget.elevation ?? 0,
              shadowOffset: widget.shadowOffset ?? Offset(0, 0),
              borderRadius: widget.navBorderRadius ?? BorderRadius.circular(0),
              color: widget.bottomNavColor ?? NUIColors.NUIWhite
          ),
          child: BottomNavigationBar(
            onTap: (int index) {
              logNUI('NUIBottomNavPager', 'Tapping on $index');
              _onNavItemClick(context, index);
            },
            backgroundColor: NUIColors.NUITransparent,
            currentIndex: _currentIndex,
            showSelectedLabels: widget.showSelectedLabels,
            showUnselectedLabels: widget.showUnselectedLabels,
            items: widget.navItems,
            elevation: 0,
            type: widget.animate ? BottomNavigationBarType.shifting : BottomNavigationBarType.fixed,
          ),
        ),
      ),
    );
  }
}
